summaryrefslogtreecommitdiffstats
path: root/src/usr/diag/mdia
diff options
context:
space:
mode:
authorPatrick Williams <iawillia@us.ibm.com>2015-01-06 15:13:56 -0600
committerA. Patrick Williams III <iawillia@us.ibm.com>2015-01-15 14:57:29 -0600
commit60e36d9749821dc522e1cfd0e164ffd4459a2895 (patch)
treed13f2f57f9129f8e4d70b2ecdfbe97cc21931421 /src/usr/diag/mdia
parent5150e1feae1154d06b2f5ba59271e481bad13e8e (diff)
downloadtalos-hostboot-60e36d9749821dc522e1cfd0e164ffd4459a2895.tar.gz
talos-hostboot-60e36d9749821dc522e1cfd0e164ffd4459a2895.zip
Fix spelling mistakes using codespell.
- See https://github.com/lucasdemarchi/codespell Change-Id: I03e102d1ebb9473b6226fa9b6edb684fa0218a2f Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/15031 Tested-by: Jenkins Server Reviewed-by: STEPHEN M. CPREK <smcprek@us.ibm.com> Reviewed-by: Zane Shelley <zshelle@us.ibm.com> Reviewed-by: Brian Silver <bsilver@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr/diag/mdia')
-rw-r--r--src/usr/diag/mdia/mdiasm.C8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/usr/diag/mdia/mdiasm.C b/src/usr/diag/mdia/mdiasm.C
index d6846ff18..f2e25eb2f 100644
--- a/src/usr/diag/mdia/mdiasm.C
+++ b/src/usr/diag/mdia/mdiasm.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2012,2014 */
+/* Contributors Listed Below - COPYRIGHT 2012,2015 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -283,10 +283,10 @@ void StateMachine::processCommandTimeout(const MonitorIDs & i_monitorIDs)
// Pending maint cmd complete, reset timer
if(mbaspa & ~mbaspamask)
{
// Commiting an info log to help debug SW timeout
if((*wit)->timeoutCnt >= MBA_TIMEOUT_LOG)
{
- MDIA_FAST("sm: commiting a SW timed out info log "
+ MDIA_FAST("sm: committing a SW timed out info log "
"for %x", get_huid(target));
/*@
@@ -566,7 +566,7 @@ bool StateMachine::scheduleWorkItem(WorkFlowProperties & i_wfp)
// schedule work items for execution in the thread pool
// see if the workFlow for this target is complete
- // and see if all phases have completed sucessfully
+ // and see if all phases have completed successfully
if(i_wfp.workItem == getWorkFlow(i_wfp).end())
{
OpenPOWER on IntegriCloud
@@ -283,10 +283,10 @@ void StateMachine::processCommandTimeout(const MonitorIDs & i_monitorIDs)
if(mbaspa & ~mbaspamask)
{
- // Commiting an info log to help debug SW timeout
+ // Committing an info log to help debug SW timeout
if((*wit)->timeoutCnt >= MBA_TIMEOUT_LOG)
{